pub enum Method {
PATCH,
POST,
PUT,
DELETE,
}Expand description
The HTTP method used in the request.
Note that GET requests do not need
signatures by definition.
Variants
PATCH
PATCH requests are used to update an existing resource.
POST
POST requests are used to create a new resource.
PUT
PUT requests are used to update an existing resource.
DELETE
GET requests are used to retrieve an existing resource.