pub enum SignatureGenerationError {
Serialization(Error),
Signing(SigningError),
}Expand description
Errors from the authorization signature generation process. This can very rarely occur from serialization (either the request could not be serialized or the serialized data can not be converted to base64), or (more likely) there was an error when undergoing the signing process.
Variants
Serialization(Error)
Signing(SigningError)